@@ -87,7 +87,7 @@ static l_int32 testcomp_mem(PIX *pixs, PIX **ppixt, l_int32 index,
 static l_int32 test_writemem(PIX *pixs, l_int32 format, char *psfile);
 static PIX *make_24_bpp_pix(PIX *pixs);
 static l_int32 get_header_data(const char *filename, l_int32 true_format);
-static void get_tiff_compression_name(char *buf, l_int32 format);
+static const char *get_tiff_compression_name(l_int32 format);
 
 LEPT_DLL extern const char *ImageFileFormatExtensions[];
 
@@ -341,7 +341,7 @@ L_REGPARAMS  *rp;
             continue;
         }
         d = pixGetDepth(pix);
-        sprintf(psname, "/tmp/lept/regout/junkps.%d", d);
+        snprintf(psname, sizeof(psname), "/tmp/lept/regout/junkps.%d", d);
         fprintf(stderr, "%d bpp\n", d);
         if (test_writemem(pix, IFF_PNM, NULL)) success = FALSE;
         if (test_writemem(pix, IFF_PS, psname)) success = FALSE;
@@ -488,6 +488,8 @@ part6:
     pixWrite(tempname, pix, IFF_PNM);
     if (get_header_data(tempname, IFF_PNM)) success = FALSE;
     pixDestroy(&pix);
+
+        /* These tiff formats work on 1 bpp images */
     pix = pixRead(FILE_1BPP);
     pixWrite(tempname, pix, IFF_TIFF_G3);
     if (get_header_data(tempname, IFF_TIFF_G3)) success = FALSE;
@@ -636,7 +638,8 @@ PIX       *pixd = NULL;
         return 1;
     }
 
-    if (format == IFF_JFIF_JPEG || format == IFF_JP2 || format == IFF_WEBP) {
+    if (format == IFF_JFIF_JPEG || format == IFF_JP2 ||
+        format == IFF_WEBP || format == IFF_TIFF_JPEG) {
         ds = pixGetDepth(pixs);
         dd = pixGetDepth(pixd);
         if (dd == 8) {
@@ -705,11 +708,11 @@ static l_int32
 get_header_data(const char  *filename,
                 l_int32      true_format)
 {
-char      buf[64];
-l_uint8  *data;
-l_int32   ret1, ret2, format1, format2;
-l_int32   w1, w2, h1, h2, d1, d2, bps1, bps2, spp1, spp2, iscmap1, iscmap2;
-size_t    size1, size2;
+const char *tiff_compression_name = "undefined";
+l_uint8    *data;
+l_int32     ret1, ret2, format1, format2;
+l_int32     w1, w2, h1, h2, d1, d2, bps1, bps2, spp1, spp2, iscmap1, iscmap2;
+size_t      size1, size2;
 
     /* Fail silently if library is not available */
 #if !HAVE_LIBJPEG
@@ -724,7 +727,7 @@ size_t    size1, size2;
     if (true_format == IFF_TIFF_G3 || true_format == IFF_TIFF_G4 ||
         true_format == IFF_TIFF_ZIP || true_format == IFF_TIFF_LZW ||
         true_format == IFF_TIFF_PACKBITS || true_format == IFF_TIFF_RLE ||
-        true_format == IFF_TIFF)
+        true_format == IFF_TIFF_JPEG || true_format == IFF_TIFF)
         return 0;
 #endif  /* !HAVE_LIBTIFF */
 
@@ -736,12 +739,16 @@ size_t    size1, size2;
     if (ret1)
         fprintf(stderr, "Error: couldn't read header data: %s\n", filename);
     else {
-        if (format1 > IFF_PNG && format1 < IFF_PNM) {
-            get_tiff_compression_name(buf, format1);
+        if (format1 == IFF_TIFF || format1 == IFF_TIFF_PACKBITS ||
+            format1 == IFF_TIFF_RLE || format1 == IFF_TIFF_G3 ||
+            format1 == IFF_TIFF_G4 || format1 == IFF_TIFF_LZW ||
+            format1 == IFF_TIFF_ZIP || format1 == IFF_TIFF_JPEG) {
+            tiff_compression_name = get_tiff_compression_name(format1);
             fprintf(stderr, "Format data for image %s with format %s:\n"
                 "  nbytes = %lu, size (w, h, d) = (%d, %d, %d)\n"
                 "  bps = %d, spp = %d, iscmap = %d\n",
-                filename, buf, (unsigned long)size1, w1, h1, d1,
+                filename, tiff_compression_name,
+                (unsigned long)size1, w1, h1, d1,
                 bps1, spp1, iscmap1);
         } else {
             fprintf(stderr, "Format data for image %s with format %s:\n"
@@ -770,8 +777,8 @@ size_t    size1, size2;
         if (size1 != size2 || format1 != format2 || w1 != w2 ||
             h1 != h2 || d1 != d2 || bps1 != bps2 || spp1 != spp2 ||
             iscmap1 != iscmap2) {
-            fprintf(stderr, "Incomsistency reading image %s with format %s\n",
-                    filename, buf);
+            fprintf(stderr, "Inconsistency reading image %s with format %s\n",
+                    filename, tiff_compression_name);
             ret2 = 1;
         }
     }
@@ -779,25 +786,27 @@ size_t    size1, size2;
 }
 
 
-static void
-get_tiff_compression_name(char    *buf,
-                          l_int32  format)
+static const char *
+get_tiff_compression_name(l_int32  format)
 {
+    const char *tiff_compression_name = "unknown";
     if (format == IFF_TIFF_G4)
-        sprintf(buf, "tiff_g4");
+        tiff_compression_name = "tiff_g4";
     else if (format == IFF_TIFF_G3)
-        sprintf(buf, "tiff_g3");
+        tiff_compression_name =  "tiff_g3";
     else if (format == IFF_TIFF_ZIP)
-        sprintf(buf, "tiff_zip");
+        tiff_compression_name =  "tiff_zip";
     else if (format == IFF_TIFF_LZW)
-        sprintf(buf, "tiff_lzw");
+        tiff_compression_name =  "tiff_lzw";
     else if (format == IFF_TIFF_RLE)
-        sprintf(buf, "tiff_rle");
+        tiff_compression_name =  "tiff_rle";
     else if (format == IFF_TIFF_PACKBITS)
-        sprintf(buf, "tiff_packbits");
+        tiff_compression_name =  "tiff_packbits";
+    else if (format == IFF_TIFF_JPEG)
+        tiff_compression_name =  "tiff_jpeg";
     else if (format == IFF_TIFF)
-        sprintf(buf, "tiff_uncompressed");
+        tiff_compression_name = "tiff_uncompressed";
     else
         fprintf(stderr, "format %d: not tiff\n", format);
-    return;
+    return tiff_compression_name;
 }
