@@ -265,7 +265,7 @@ PTA       *pta;
             ptaGetIPt(pta, i + 1, &x2, &y2);
             pixRenderLineArb(pix1, x1, y1, x2, y2, 2, 255, 0, 0);
         }
-        pixWrite("/tmp/lept/baseline/baselines.png", pix1, IFF_PNG);
+        pixWriteDebug("/tmp/lept/baseline/baselines.png", pix1, IFF_PNG);
         pixaAddPix(pixadb, pixScale(pix1, 0.25, 0.25), L_INSERT);
         pixDestroy(&pix1);
     }
@@ -384,7 +384,7 @@ PTA       *ptas, *ptad;
  *          to remove keystoning in the src.
  * </pre>
  */
-l_int32
+l_ok
 pixGetLocalSkewTransform(PIX       *pixs,
                          l_int32    nslices,
                          l_int32    redsweep,
@@ -546,7 +546,7 @@ PTA       *pta;
     for (i = 0; i < nslices; i++) {
         ystart = L_MAX(0, hs * i - ovlap);
         yend = L_MIN(h - 1, hs * (i + 1) + ovlap);
-        ycenter = (ystart + yend) / 2;
+        ycenter = (l_float32)(ystart + yend) / 2;
         box = boxCreate(0, ystart, w, yend - ystart + 1);
         pix = pixClipRectangle(pixs, box, NULL);
         pixFindSkewSweepAndSearch(pix, &angle, &conf, redsweep, redsearch,
