@@ -110,7 +110,7 @@ static BOXA *boxaApplyDisparity(L_DEWARP *dew, BOXA *boxa, l_int32 direction,
  *          these hold approximately 16 bytes for each pixel in pixs.
  * </pre>
  */
-l_int32
+l_ok
 dewarpaApplyDisparity(L_DEWARPA   *dewa,
                       l_int32      pageno,
                       PIX         *pixs,
@@ -150,8 +150,8 @@ PIX       *pixv, *pixh;
         pixDisplayWithTitle(pixv, 300, 0, "pixv", 1);
         lept_rmdir("lept/dewapply");  /* remove previous images */
         lept_mkdir("lept/dewapply");
-        pixWrite("/tmp/lept/dewapply/001.png", pixs, IFF_PNG);
-        pixWrite("/tmp/lept/dewapply/002.png", pixv, IFF_PNG);
+        pixWriteDebug("/tmp/lept/dewapply/001.png", pixs, IFF_PNG);
+        pixWriteDebug("/tmp/lept/dewapply/002.png", pixv, IFF_PNG);
     }
 
         /* Optionally, correct for horizontal disparity */
@@ -164,7 +164,7 @@ PIX       *pixv, *pixh;
                 *ppixd = pixh;
                 if (debugfile) {
                     pixDisplayWithTitle(pixh, 600, 0, "pixh", 1);
-                    pixWrite("/tmp/lept/dewapply/003.png", pixh, IFF_PNG);
+                    pixWriteDebug("/tmp/lept/dewapply/003.png", pixh, IFF_PNG);
                 }
             } else {
                 L_ERROR("horiz disparity failed on page %d\n",
@@ -176,7 +176,7 @@ PIX       *pixv, *pixh;
     if (debugfile) {
         dew1 = dewarpaGetDewarp(dewa, pageno);
         dewarpDebug(dew1, "lept/dewapply", 0);
-        convertFilesToPdf("/tmp/lept/dewapply", NULL, 135, 1.0, 0, 0,
+        convertFilesToPdf("/tmp/lept/dewapply", NULL, 250, 1.0, 0, 0,
                          "Dewarp Apply Disparity", debugfile);
         fprintf(stderr, "pdf file: %s\n", debugfile);
     }
@@ -533,7 +533,7 @@ PIX        *pixd;
  *      (4) If an error occurs, a copy of the input boxa is returned.
  * </pre>
  */
-l_int32
+l_ok
 dewarpaApplyDisparityBoxa(L_DEWARPA   *dewa,
                           l_int32      pageno,
                           PIX         *pixs,
@@ -579,12 +579,12 @@ PIX       *pixv, *pixh;
         lept_mkdir("lept/dewboxa");
         pix1 = pixConvertTo32(pixs);
         pixRenderBoxaArb(pix1, boxas, 2, 255, 0, 0);
-        pixWrite("/tmp/lept/dewboxa/01.png", pix1, IFF_PNG);
+        pixWriteDebug("/tmp/lept/dewboxa/01.png", pix1, IFF_PNG);
         pixDestroy(&pix1);
         pixv = pixApplyVertDisparity(dew, pixs, 255);
         pix1 = pixConvertTo32(pixv);
         pixRenderBoxaArb(pix1, boxav, 2, 0, 255, 0);
-        pixWrite("/tmp/lept/dewboxa/02.png", pix1, IFF_PNG);
+        pixWriteDebug("/tmp/lept/dewboxa/02.png", pix1, IFF_PNG);
         pixDestroy(&pix1);
     }
 
@@ -604,7 +604,7 @@ PIX       *pixv, *pixh;
                     pixh = pixApplyHorizDisparity(dew, pixv, 255);
                     pix1 = pixConvertTo32(pixh);
                     pixRenderBoxaArb(pix1, boxah, 2, 0, 0, 255);
-                    pixWrite("/tmp/lept/dewboxa/03.png", pix1, IFF_PNG);
+                    pixWriteDebug("/tmp/lept/dewboxa/03.png", pix1, IFF_PNG);
                     pixDestroy(&pixh);
                     pixDestroy(&pix1);
                 }
@@ -725,7 +725,7 @@ PTA        *ptas, *ptad;
  *          resolution arrays can be reconstructed.
  * </pre>
  */
-l_int32
+l_ok
 dewarpMinimize(L_DEWARP  *dew)
 {
 L_DEWARP  *dewt;
@@ -774,14 +774,14 @@ L_DEWARP  *dewt;
  *              relative to pixs.  Thus, (x,y) gives the amount of
  *              slope extension in (left, top).  The (right, bottom)
  *              extension is then determined by the size of pixs and
- *              (x,y); the values should never be \< 0.
+ *              (x,y); the values should never be < 0.
  *          (b) If the arrays exist and pixs is too large, the existing
  *              full res arrays are destroyed and new ones are made,
  *              again using (x,y) to determine the extension in the
  *              four directions.
  * </pre>
  */
-l_int32
+l_ok
 dewarpPopulateFullRes(L_DEWARP  *dew,
                       PIX       *pix,
                       l_int32    x,
@@ -949,8 +949,8 @@ FPIX      *fpixd;
  *          ends of textlines.
  *      (2) Usage:
  *            l_int32 xwid = [extra width to be added to fpix and image]
- *            FPix *fpix = fpixExtraHorizDisparity(dew-\>fullvdispar, 0, \&xwid);
- *            fpixLinearCombination(dew-\>fullhdispar, dew-\>fullhdispar,
+ *            FPix *fpix = fpixExtraHorizDisparity(dew->fullvdispar, 0, &xwid);
+ *            fpixLinearCombination(dew->fullhdispar, dew->fullhdispar,
  *                                  fpix, 1.0, 1.0);
  * </pre>
  */
