@@ -239,7 +239,7 @@ static char wplstrm[][10] = {"- wpls", "- wpls2", "- wpls3", "- wpls4",
  *      (2) See fmorphautogen1() and fmorphautogen2() for details.
  * </pre>
  */
-l_int32
+l_ok
 fmorphautogen(SELA        *sela,
               l_int32      fileindex,
               const char  *filename)
@@ -274,12 +274,12 @@ l_int32  ret1, ret2;
  *          opening or closing for any of the sels in the input sela.
  *      (2) The fileindex parameter is inserted into the output
  *          filename, as described below.
- *      (3) If filename == NULL, the output file is fmorphgen.<n>.c,
- *          where <n> is equal to the 'fileindex' parameter.
- *      (4) If filename != NULL, the output file is <filename>.<n>.c.
+ *      (3) If filename == NULL, the output file is fmorphgen.[n].c,
+ *          where [n] is equal to the %fileindex parameter.
+ *      (4) If filename != NULL, the output file is [%filename].[n].c.
  * </pre>
  */
-l_int32
+l_ok
 fmorphautogen1(SELA        *sela,
                l_int32      fileindex,
                const char  *filename)
@@ -482,9 +482,9 @@ SARRAY  *sa1, *sa2, *sa3;
  *          in the input sela.
  *      (2) The fileindex parameter is inserted into the output
  *          filename, as described below.
- *      (3) If filename == NULL, the output file is fmorphgenlow.<n>.c,
- *          where <n> is equal to the 'fileindex' parameter.
- *      (4) If filename != NULL, the output file is <filename>low.<n>.c.
+ *      (3) If filename == NULL, the output file is fmorphgenlow.[n].c,
+ *          where [n] is equal to the 'fileindex' parameter.
+ *      (4) If filename != NULL, the output file is [filename]low.[n].c.
  */
 l_int32
 fmorphautogen2(SELA        *sela,
@@ -547,10 +547,6 @@ SEL     *sel;
     str_doc2 = stringNew(bigbuf);
     sprintf(bigbuf, " *             void       ferode_%d_*()", fileindex);
     str_doc3 = stringNew(bigbuf);
-    sprintf(bigbuf, " *  fmorphopgen_low_%d()", fileindex);
-    str_doc4 = stringNew(bigbuf);
-    sprintf(bigbuf, "fmorphopgen_low_%d(l_uint32  *datad,", fileindex);
-    str_def1 = stringNew(bigbuf);
 
         /* Output to this sa */
     sa4 = sarrayCreate(0);
@@ -580,6 +576,12 @@ SEL     *sel;
         sarrayAddString(sa4, linestr, L_INSERT);
     }
 
+        /* More strings with function names */
+    sprintf(bigbuf, " *  fmorphopgen_low_%d()", fileindex);
+    str_doc4 = stringNew(bigbuf);
+    sprintf(bigbuf, "fmorphopgen_low_%d(l_uint32  *datad,", fileindex);
+    str_def1 = stringNew(bigbuf);
+
         /* Insert function header */
     sarrayParseRange(sa1, newstart, &actstart, &end, &newstart, "--", 0);
     sarrayAppendRange(sa4, sa1, actstart, end);
@@ -797,7 +799,7 @@ SARRAY  *sa;
                 if (optype == L_MORPH_DILATE) {
                     dely = sel->cy - i;
                     delx = sel->cx - j;
-                } else if (optype == L_MORPH_ERODE) {
+                } else {  /* optype == L_MORPH_ERODE */
                     dely = i - sel->cy;
                     delx = j - sel->cx;
                 }
