@@ -98,7 +98,7 @@ static const l_int32  MinHeight = 100;
  *      (2) Passing in %pixadb enables debug output.
  * </pre>
  */
-l_int32
+l_ok
 pixGetRegionsBinary(PIX   *pixs,
                     PIX  **ppixhm,
                     PIX  **ppixtm,
@@ -202,9 +202,8 @@ PIX     *pixtb;    /* textblock mask */
         PIXCMAP  *cmap;
         PTAA     *ptaa;
         ptaa = pixGetOuterBordersPtaa(pixtb);
-        lept_mkdir("lept");
         lept_mkdir("lept/pageseg");
-        ptaaWrite("/tmp/lept/pageseg/tb_outlines.ptaa", ptaa, 1);
+        ptaaWriteDebug("/tmp/lept/pageseg/tb_outlines.ptaa", ptaa, 1);
         pix1 = pixRenderRandomCmapPtaa(pixtb, ptaa, 1, 16, 1);
         cmap = pixGetColormap(pix1);
         pixcmapResetColor(cmap, 0, 130, 130, 130);
@@ -218,9 +217,9 @@ PIX     *pixtb;    /* textblock mask */
         bahm = pixConnComp(pixhm, NULL, 4);
         batm = pixConnComp(pixtm, NULL, 4);
         batb = pixConnComp(pixtb, NULL, 4);
-        boxaWrite("/tmp/lept/pageseg/htmask.boxa", bahm);
-        boxaWrite("/tmp/lept/pageseg/textmask.boxa", batm);
-        boxaWrite("/tmp/lept/pageseg/textblock.boxa", batb);
+        boxaWriteDebug("/tmp/lept/pageseg/htmask.boxa", bahm);
+        boxaWriteDebug("/tmp/lept/pageseg/textmask.boxa", batm);
+        boxaWriteDebug("/tmp/lept/pageseg/textblock.boxa", batb);
         boxaDestroy(&bahm);
         boxaDestroy(&batm);
         boxaDestroy(&batb);
@@ -274,10 +273,10 @@ pixGenHalftoneMask(PIX      *pixs,
 /*!
  * \brief   pixGenerateHalftoneMask()
  *
- * \param[in]    pixs 1 bpp, assumed to be 150 to 200 ppi
- * \param[out]   ppixtext [optional] text part of pixs
- * \param[out]   phtfound [optional] 1 if the mask is not empty
- * \param[in]    pixadb  input for collecting debug pix; use NULL to skip
+ * \param[in]    pixs      1 bpp, assumed to be 150 to 200 ppi
+ * \param[out]   ppixtext  [optional] text part of pixs
+ * \param[out]   phtfound  [optional] 1 if the mask is not empty
+ * \param[in]    pixadb    input for collecting debug pix; use NULL to skip
  * \return  pixd halftone mask, or NULL on error
  *
  * <pre>
@@ -353,10 +352,10 @@ PIX     *pix1, *pix2, *pixhs, *pixhm, *pixd;
 /*!
  * \brief   pixGenTextlineMask()
  *
- * \param[in]    pixs 1 bpp, assumed to be 150 to 200 ppi
- * \param[out]   ppixvws vertical whitespace mask
- * \param[out]   ptlfound [optional] 1 if the mask is not empty
- * \param[in]    pixadb  input for collecting debug pix; use NULL to skip
+ * \param[in]    pixs      1 bpp, assumed to be 150 to 200 ppi
+ * \param[out]   ppixvws   vertical whitespace mask
+ * \param[out]   ptlfound  [optional] 1 if the mask is not empty
+ * \param[in]    pixadb    input for collecting debug pix; use NULL to skip
  * \return  pixd textline mask, or NULL on error
  *
  * <pre>
@@ -443,9 +442,9 @@ PIX     *pix1, *pix2, *pixvws, *pixd;
 /*!
  * \brief   pixGenTextblockMask()
  *
- * \param[in]    pixs 1 bpp, textline mask, assumed to be 150 to 200 ppi
- * \param[in]    pixvws vertical white space mask
- * \param[in]    pixadb  input for collecting debug pix; use NULL to skip
+ * \param[in]    pixs     1 bpp, textline mask, assumed to be 150 to 200 ppi
+ * \param[in]    pixvws   vertical white space mask
+ * \param[in]    pixadb   input for collecting debug pix; use NULL to skip
  * \return  pixd textblock mask, or NULL on error
  *
  * <pre>
@@ -520,17 +519,13 @@ PIX     *pix1, *pix2, *pix3, *pixd;
  *                          should be larger than 50; typically about 70
  * \param[in]    erasedist  when conditions are satisfied, erase anything
  *                          within this distance of the edge;
- *                          typically 30 at 2x reduction
- * \param[in]    pagenum    use for debugging when called repeatedly; labels
- *                          debug images that are assembled into pdfdir
- * \param[in]    showmorph  set to a negative integer to show steps in
- *                          generating masks; this is typically used
+ *                          typically 20-30 at 2x reduction
+ * \param[in]    showmorph  debug: set to a negative integer to show steps
+ *                          in generating masks; this is typically used
  *                          for debugging region extraction
- * \param[in]    display    set to 1  to display mask and selected region
- *                          for debugging a single page
- * \param[in]    pdfdir     subdirectory of /tmp where images showing the
- *                          result are placed when called repeatedly; use
- *                          null if no output requested
+ * \param[in]    pixac      debug: allocate outside and pass this in to
+ *                          accumulate results of each call to this function,
+ *                          which can be displayed in a mosaic or a pdf.
  * \return  box region including foreground, with some pixel noise
  *                   removed, or NULL if not found
  *
@@ -539,30 +534,24 @@ PIX     *pix1, *pix2, *pix3, *pixd;
  *      (1) This doesn't simply crop to the fg.  It attempts to remove
  *          pixel noise and junk at the edge of the image before cropping.
  *          The input %threshold is used if pixs is not 1 bpp.
- *      (2) There are several debugging options, determined by the
- *          last 4 arguments.
- *      (3) This is not intended to work on small thumbnails.  The
+ *      (2) This is not intended to work on small thumbnails.  The
  *          dimensions of pixs must be at least MinWidth x MinHeight.
- *      (4) If you want pdf output of results when called repeatedly,
- *          the pagenum arg labels the images written, which go into
- *          /tmp/lept/<pdfdir>/<pagenum>.png.  In that case,
- *          you would clean out the /tmp directory before calling this
- *          function on each page:
- *              lept_rmdir("/lept/<pdfdir>");
- *              lept_mkdir("/lept/<pdfdir>");
+ *      (3) Debug: set showmorph to display the intermediate image in
+ *          the morphological operations on this page.
+ *      (4) Debug: to get pdf output of results when called repeatedly,
+ *          call with an existing pixac, which will add an image of this page,
+ *          with the fg outlined.  If no foreground is found, there is
+ *          no output for this page image.
  * </pre>
  */
 BOX *
-pixFindPageForeground(PIX         *pixs,
-                      l_int32      threshold,
-                      l_int32      mindist,
-                      l_int32      erasedist,
-                      l_int32      pagenum,
-                      l_int32      showmorph,
-                      l_int32      display,
-                      const char  *pdfdir)
+pixFindPageForeground(PIX     *pixs,
+                      l_int32  threshold,
+                      l_int32  mindist,
+                      l_int32  erasedist,
+                      l_int32  showmorph,
+                      PIXAC   *pixac)
 {
-char     buf[64];
 l_int32  flag, nbox, intersects;
 l_int32  w, h, bx, by, bw, bh, left, right, top, bottom;
 PIX     *pixb, *pixb2, *pixseed, *pixsf, *pixm, *pix1, *pixg2;
@@ -584,15 +573,19 @@ BOXA    *ba1, *ba2;
          * components of the binarized image for which there was at least
          * one seed pixel.  Also clear out any components that are within
          * 10 pixels of the edge at 2x reduction. */
-    flag = (showmorph) ? -1 : 0;  /* if showmorph == -1, write intermediate
-                                   * images to /tmp/lept/seq_output_1.pdf */
+    flag = (showmorph) ? 100 : 0;
     pixb = pixConvertTo1(pixs, threshold);
     pixb2 = pixScale(pixb, 0.5, 0.5);
-    pixseed = pixMorphSequence(pixb2, "o1.2 + c9.9 + o3.5", flag);
+    pixseed = pixMorphSequence(pixb2, "o1.2 + c9.9 + o3.3", flag);
+    pix1 = pixMorphSequence(pixb2, "o50.1", 0);
+    pixOr(pixseed, pixseed, pix1);
+    pixDestroy(&pix1);
+    pix1 = pixMorphSequence(pixb2, "o1.50", 0);
+    pixOr(pixseed, pixseed, pix1);
+    pixDestroy(&pix1);
     pixsf = pixSeedfillBinary(NULL, pixseed, pixb2, 8);
     pixSetOrClearBorder(pixsf, 10, 10, 10, 10, PIX_SET);
     pixm = pixRemoveBorderConnComps(pixsf, 8);
-    if (display) pixDisplay(pixm, 100, 100);
 
         /* Now, where is the main block of text?  We want to remove noise near
          * the edge of the image, but to do that, we have to be convinced that
@@ -600,7 +593,6 @@ BOXA    *ba1, *ba2;
          * and close enough to the edge.  For each edge, if the block
          * is more than mindist from that edge, then clean 'erasedist'
          * pixels from the edge. */
-    if (flag == -1) flag = -2;  /* write a pdf to /tmp/lept/seq_output_2.pdf */
     pix1 = pixMorphSequence(pixm, "c50.50", flag);
     ba1 = pixConnComp(pix1, NULL, 8);
     ba2 = boxaSort(ba1, L_SORT_BY_AREA, L_SORT_DECREASING, NULL);
@@ -629,33 +621,20 @@ BOXA    *ba1, *ba2;
     if (boxfg) {
         boxin = boxCreate(0.1 * w, 0, 0.8 * w, h);
         boxIntersects(boxfg, boxin, &intersects);
-        if (!intersects) {
-            L_INFO("found only noise on page %d\n", procName, pagenum);
-            boxDestroy(&boxfg);
-        }
         boxDestroy(&boxin);
+        if (!intersects) boxDestroy(&boxfg);
     }
 
     boxd = NULL;
-    if (!boxfg) {
-        L_INFO("no fg region found for page %d\n", procName, pagenum);
-    } else {
+    if (boxfg) {
         boxAdjustSides(boxfg, boxfg, -2, 2, -2, 2);  /* tiny expansion */
         boxd = boxTransform(boxfg, 0, 0, 2.0, 2.0);
 
-            /* Write image showing box for this page.  This is to be
-             * bundled up into a pdf of all the pages, which can be
-             * generated by convertFilesToPdf()  */
-        if (pdfdir) {
-            snprintf(buf, sizeof(buf), "lept/%s", pdfdir);
-            lept_mkdir(buf);
-
+            /* Save the debug image showing the box for this page */
+        if (pixac) {
             pixg2 = pixConvert1To4Cmap(pixb);
             pixRenderBoxArb(pixg2, boxd, 3, 255, 0, 0);
-            snprintf(buf, sizeof(buf), "/tmp/lept/%s/%04d.png",
-                     pdfdir, pagenum);
-            if (display) pixDisplay(pixg2, 700, 100);
-            pixWrite(buf, pixg2, IFF_PNG);
+            pixacompAddPix(pixac, pixg2, IFF_DEFAULT);
             pixDestroy(&pixg2);
         }
     }
@@ -695,7 +674,7 @@ BOXA    *ba1, *ba2;
  *          (possibly split) components are extracted.
  * </pre>
  */
-l_int32
+l_ok
 pixSplitIntoCharacters(PIX     *pixs,
                        l_int32  minw,
                        l_int32  minh,
@@ -781,11 +760,11 @@ PIXA   *pixa1, *pixadb;
 /*!
  * \brief   pixSplitComponentWithProfile()
  *
- * \param[in]    pixs 1 bpp, exactly one connected component
- * \param[in]    delta distance used in extrema finding in a numa; typ. 10
- * \param[in]    mindel minimum required difference between profile minimum
- *                      and profile values +2 and -2 away; typ. 7
- * \param[out]   ppixdebug [optional] debug image of splitting
+ * \param[in]    pixs       1 bpp, exactly one connected component
+ * \param[in]    delta      distance used in extrema finding in a numa; typ. 10
+ * \param[in]    mindel     minimum required difference between profile
+ *                          minimum and profile values +2 and -2 away; typ. 7
+ * \param[out]   ppixdebug  [optional] debug image of splitting
  * \return  boxa of c.c. after splitting, or NULL on error
  *
  * <pre>
@@ -909,16 +888,16 @@ PIX      *pix1, *pixdb;
 /*!
  * \brief   pixExtractTextlines()
  *
- * \param[in]    pixs       any depth, assumed to have nearly horizontal text
- * \param[in]    maxw, maxh initial filtering: remove any components in pixs
- *                          with components larger than maxw or maxh
- * \param[in]    minw, minh final filtering: remove extracted 'lines'
- *                          with sizes smaller than minw or minh; use
- *                          0 for default.
- * \param[in]    adjw, adjh final adjustment of boxes representing each
- *                          text line.  If > 0, these increase the box
- *                          size at each edge by this amount.
- * \param[in]    pixadb     pixa for saving intermediate steps; NULL to omit
+ * \param[in]    pixs        any depth, assumed to have nearly horizontal text
+ * \param[in]    maxw, maxh  initial filtering: remove any components in pixs
+ *                           with components larger than maxw or maxh
+ * \param[in]    minw, minh  final filtering: remove extracted 'lines'
+ *                           with sizes smaller than minw or minh; use
+ *                           0 for default.
+ * \param[in]    adjw, adjh  final adjustment of boxes representing each
+ *                           text line.  If > 0, these increase the box
+ *                           size at each edge by this amount.
+ * \param[in]    pixadb      pixa for saving intermediate steps; NULL to omit
  * \return  pixa of textline images, including bounding boxes, or
  *                    NULL on error
  *
@@ -1057,14 +1036,14 @@ PIXA    *pixa1, *pixa2, *pixa3;
 /*!
  * \brief   pixExtractRawTextlines()
  *
- * \param[in]    pixs       any depth, assumed to have nearly horizontal text
- * \param[in]    maxw, maxh initial filtering: remove any components in pixs
- *                          with components larger than maxw or maxh;
- *                          use 0 for default values.
- * \param[in]    adjw, adjh final adjustment of boxes representing each
- *                          text line.  If > 0, these increase the box
- *                          size at each edge by this amount.
- * \param[in]    pixadb     pixa for saving intermediate steps; NULL to omit
+ * \param[in]    pixs        any depth, assumed to have nearly horizontal text
+ * \param[in]    maxw, maxh  initial filtering: remove any components in pixs
+ *                           with components larger than maxw or maxh;
+ *                           use 0 for default values.
+ * \param[in]    adjw, adjh  final adjustment of boxes representing each
+ *                           text line.  If > 0, these increase the box
+ *                           size at each edge by this amount.
+ * \param[in]    pixadb      pixa for saving intermediate steps; NULL to omit
  * \return  pixa of textline images, including bounding boxes, or
  *                    NULL on error
  *
@@ -1101,11 +1080,10 @@ pixExtractRawTextlines(PIX     *pixs,
                        PIXA    *pixadb)
 {
 char     buf[64];
-l_int32  i, n, res, csize, empty;
-BOX     *box;
+l_int32  res, csize, empty;
 BOXA    *boxa1, *boxa2, *boxa3;
 BOXAA   *baa1;
-PIX     *pix1, *pix2, *pix3, *pix4, *pix5;
+PIX     *pix1, *pix2, *pix3;
 PIXA    *pixa1, *pixa2;
 
     PROCNAME("pixExtractRawTextlines");
@@ -1221,7 +1199,7 @@ PIXA    *pixa1, *pixa2;
  *      (4) For debug output, input a pre-allocated pixa.
  * </pre>
  */
-l_int32
+l_ok
 pixCountTextColumns(PIX       *pixs,
                     l_float32  deltafract,
                     l_float32  peakfract,
@@ -1369,7 +1347,7 @@ PIX       *pix1, *pix2, *pix3, *pix4, *pix5;
  *      (7) For debug output, input a pre-allocated pixa.
  * </pre>
  */
-l_int32
+l_ok
 pixDecideIfText(PIX      *pixs,
                 BOX      *box,
                 l_int32  *pistext,
@@ -1437,7 +1415,7 @@ SEL       *sel1;
     }
 
     if (pixadb) {
-        bmf = bmfCreate(NULL, 8);
+        bmf = bmfCreate(NULL, 6);
         pixaAddPixWithText(pixadb, pix1, 1, bmf, "threshold/crop to binary",
                            0x0000ff00, L_ADD_BELOW);
         pixaAddPixWithText(pixadb, pix3, 2, bmf, "hit-miss for vertical line",
@@ -1529,13 +1507,13 @@ SEL       *sel1;
 /*!
  * \brief   pixFindThreshFgExtent()
  *
- * \param[in]    pixs      1 bpp
- * \param[in]    thresh    threshold number of pixels in row
- * \param[out]   ptop      [optional] location of top of region
- * \param[out]   pbot      [optional] location of bottom of region
+ * \param[in]    pixs     1 bpp
+ * \param[in]    thresh   threshold number of pixels in row
+ * \param[out]   ptop     [optional] location of top of region
+ * \param[out]   pbot     [optional] location of bottom of region
  * \return  0 if OK, 1 on error
  */
-l_int32
+l_ok
 pixFindThreshFgExtent(PIX      *pixs,
                       l_int32   thresh,
                       l_int32  *ptop,
@@ -1585,9 +1563,10 @@ NUMA     *na;
 /*!
  * \brief   pixDecideIfTable()
  *
- * \param[in]    pixs      any depth, 300 ppi
+ * \param[in]    pixs      any depth, any resolution >= 75 ppi
  * \param[in]    box       [optional] if null, use entire pixs
- * \param[out]   pistable  1 if table; 0 if text only; -1 if not determined
+ * \param[in]    orient    L_PORTRAIT_MODE, L_LANDSCAPE_MODE
+ * \param[out]   pscore    0 - 4; -1 if not determined
  * \param[in]    pixadb    [optional] pre-allocated, for showing intermediate
  *                         computation; use NULL to skip
  * \return  0 if OK, 1 on error
@@ -1596,36 +1575,72 @@ NUMA     *na;
  * Notes:
  *      (1) It is assumed that pixs has the correct resolution set.
  *          If the resolution is 0, we assume it is 300 ppi and issue a warning.
- *      (2) Most of the processing takes place at 75 ppi.
- *      (3) Three numbers are determined, for horizontal and vertical
- *          fg and bg lines.  From these, four tests are made to decide
- *          if there is a table occupying a significant part of the image.
- *      (4) For debug output, input a pre-allocated pixa.
+ *      (2) If %orient == L_LANDSCAPE_MODE, the image is rotated 90 degrees
+ *          clockwise before being analyzed.
+ *      (3) The interpretation of the returned score:
+ *            -1     undetermined
+ *             0     no table
+ *             1     unlikely to have a table
+ *             2     likely to have a table
+ *             3     even more likely to have a table
+ *             4     extremely likely to have a table
+ *          * Setting the condition for finding a table at score >= 2 works
+ *            well, except for false positives on kanji and landscape text.
+ *          * These false positives can be removed by setting the condition
+ *            at score >= 3, but recall is lowered because it will not find
+ *            tables without either horizontal or vertical lines.
+ *      (4) Most of the processing takes place at 75 ppi.
+ *      (5) Internally, three numbers are determined, for horizontal and
+ *          vertical fg lines, and for vertical bg lines.  From these,
+ *          four tests are made to decide if there is a table occupying
+ *          a significant part of the image.
+ *      (6) Images have arbitrary content and would be likely to trigger
+ *          this detector, so they are checked for first, and if found,
+ *          return with a 0 (no table) score.
+ *      (7) Musical scores (tablature) are likely to trigger the detector.
+ *      (8) Tables of content with more than 2 columns are likely to
+ *          trigger the detector.
+ *      (9) For debug output, input a pre-allocated pixa.
  * </pre>
  */
-l_int32
+l_ok
 pixDecideIfTable(PIX      *pixs,
                  BOX      *box,
-                 l_int32  *pistable,
+                 l_int32   orient,
+                 l_int32  *pscore,
                  PIXA     *pixadb)
 {
-l_int32  i, empty, nhb, nvb, nvw, score;
-PIX     *pix1, *pix2, *pix3, *pix4, *pix5, *pix6, *pix7;
+l_int32  empty, nhb, nvb, nvw, score, htfound;
+PIX     *pix1, *pix2, *pix3, *pix4, *pix5, *pix6, *pix7, *pix8, *pix9;
 
     PROCNAME("pixDecideIfTable");
 
-    if (!pistable)
-        return ERROR_INT("&istable not defined", procName, 1);
-    *pistable = -1;
+    if (!pscore)
+        return ERROR_INT("&score not defined", procName, 1);
+    *pscore = -1;
     if (!pixs)
         return ERROR_INT("pixs not defined", procName, 1);
 
+        /* Check if there is an image region.  First convert to 1 bpp
+         * at 175 ppi.  If an image is found, assume there is no table.  */
+    pix1 = pixPrepare1bpp(pixs, box, 0.1, 175);
+    pix2 = pixGenerateHalftoneMask(pix1, NULL, &htfound, NULL);
+    if (htfound && pixadb) pixaAddPix(pixadb, pix2, L_COPY);
+    pixDestroy(&pix1);
+    pixDestroy(&pix2);
+    if (htfound) {
+        *pscore = 0;
+        L_INFO("pix has an image region\n", procName);
+        return 0;
+    }
+
         /* Crop, convert to 1 bpp, 75 ppi */
-    if ((pix1 = pixPrepare1bpp(pixs, box, 0.1, 75)) == NULL)
+    if ((pix1 = pixPrepare1bpp(pixs, box, 0.05, 75)) == NULL)
         return ERROR_INT("pix1 not made", procName, 1);
 
     pixZero(pix1, &empty);
     if (empty) {
+        *pscore = 0;
         pixDestroy(&pix1);
         L_INFO("pix is empty\n", procName);
         return 0;
@@ -1640,16 +1655,22 @@ PIX     *pix1, *pix2, *pix3, *pix4, *pix5, *pix6, *pix7;
          * is not at 300 ppi.   */
     pix2 = pixDilateBrick(NULL, pix1, 2, 2);
 
-        /* Deskew both horizontally and vertically */
+        /* Deskew both horizontally and vertically; rotate by 90
+         * degrees if in landscape mode. */
     pix3 = pixDeskewBoth(pix2, 1);
     if (pixadb) {
         pixaAddPix(pixadb, pix2, L_COPY);
         pixaAddPix(pixadb, pix3, L_COPY);
     }
+    if (orient == L_LANDSCAPE_MODE)
+        pix4 = pixRotate90(pix3, 1);
+    else
+        pix4 = pixClone(pix3);
     pixDestroy(&pix1);
     pixDestroy(&pix2);
-    pix1 = pixClone(pix3);
     pixDestroy(&pix3);
+    pix1 = pixClone(pix4);
+    pixDestroy(&pix4);
 
         /* Look for horizontal and vertical lines */
     pix2 = pixMorphSequence(pix1, "o100.1 + c1.4", 0);
@@ -1658,7 +1679,6 @@ PIX     *pix1, *pix2, *pix3, *pix4, *pix5, *pix6, *pix7;
     pix5 = pixSeedfillBinary(NULL, pix4, pix1, 8);
     pix6 = pixOr(NULL, pix3, pix5);
     if (pixadb) {
-        pixaAddPix(pixadb, pix1, L_COPY);
         pixaAddPix(pixadb, pix2, L_COPY);
         pixaAddPix(pixadb, pix4, L_COPY);
         pixaAddPix(pixadb, pix3, L_COPY);
@@ -1672,23 +1692,35 @@ PIX     *pix1, *pix2, *pix3, *pix4, *pix5, *pix6, *pix7;
     pixSubtract(pix1, pix1, pix6);
     if (pixadb) pixaAddPix(pixadb, pix1, L_COPY);
 
-        /* Look for vertical white space.  Use a 2,2 rank reduction, which
-         * is neutral in density, to do the final processing at 19 ppi. 
-         * The vertical opening is then about 3 inches on a 300 ppi image. */
-    pixInvert(pix1, pix1);
-    pix7 = pixMorphSequence(pix1, "r22 + o1.60", 0);
-    pixCountConnComp(pix7, 8, &nvw);  /* number of vertical white lines */
-    if (pixadb) pixaAddPix(pixadb, pixScale(pix7, 4.0, 4.0), L_INSERT);
+        /* Remove noise pixels */
+    pix7 = pixMorphSequence(pix1, "c4.1 + o8.1", 0);
+    if (pixadb) pixaAddPix(pixadb, pix7, L_COPY);
+
+        /* Look for vertical white space.  Invert to convert white bg
+         * to fg.  Use a single rank-1 2x reduction, which closes small
+         * fg holes, for the final processing at 37.5 ppi.
+         * The vertical opening is then about 3 inches on a 300 ppi image.
+         * We also remove vertical whitespace that is less than 5 pixels
+         * wide at this resolution (about 0.1 inches) */
+    pixInvert(pix7, pix7);
+    pix8 = pixMorphSequence(pix7, "r1 + o1.100", 0);
+    pix9 = pixSelectBySize(pix8, 5, 0, 8, L_SELECT_WIDTH,
+                           L_SELECT_IF_GTE, NULL);
+    pixCountConnComp(pix9, 8, &nvw);  /* number of vertical white lines */
+    if (pixadb) {
+        pixaAddPix(pixadb, pixScale(pix8, 2.0, 2.0), L_INSERT);
+        pixaAddPix(pixadb, pixScale(pix9, 2.0, 2.0), L_INSERT);
+    }
 
         /* Require at least 2 of the following 4 conditions for a table.
          * Some tables do not have black (fg) lines, and for those we
          * require more than 6 long vertical whitespace (bg) lines.  */
     score = 0;
-    if (nhb > 2) score++;
+    if (nhb > 1) score++;
     if (nvb > 2) score++;
     if (nvw > 3) score++;
     if (nvw > 6) score++;
-    *pistable = (score > 1) ? 1 : 0;
+    *pscore = score;
 
     pixDestroy(&pix1);
     pixDestroy(&pix2);
@@ -1697,7 +1729,9 @@ PIX     *pix1, *pix2, *pix3, *pix4, *pix5, *pix6, *pix7;
     pixDestroy(&pix5);
     pixDestroy(&pix6);
     pixDestroy(&pix7);
-    return 1;
+    pixDestroy(&pix8);
+    pixDestroy(&pix9);
+    return 0;
 }
 
 
@@ -1713,7 +1747,7 @@ PIX     *pix1, *pix2, *pix3, *pix4, *pix5, *pix6, *pix7;
  *                          300 ppi; use 0 to skip scaling.
  * \return  pixd if OK, NULL on error
  *
- * </pre>
+ * <pre>
  * Notes:
  *      (1) This handles some common pre-processing operations,
  *          where the page segmentation algorithm takes a 1 bpp image.
@@ -1804,7 +1838,7 @@ PIX       *pix1, *pix2, *pix3, *pix4, *pix5;
  *      (1) Caller should check that return bg value is > 0.
  * </pre>
  */
-l_int32
+l_ok
 pixEstimateBackground(PIX       *pixs,
                       l_int32    darkthresh,
                       l_float32  edgecrop,
@@ -1888,7 +1922,7 @@ PIX       *pix1, *pix2, *pixm;
  *          the largest 50 boxes takes about 0.2 seconds.
  * </pre>
  */
-l_int32
+l_ok
 pixFindLargeRectangles(PIX          *pixs,
                        l_int32       polarity,
                        l_int32       nrect,
@@ -1920,6 +1954,7 @@ PIX     *pix;
     boxa = boxaCreate(nrect);
     *pboxa = boxa;
 
+        /* Sequentially find largest rectangle and fill with opposite color */
     for (i = 0; i < nrect; i++) {
         if (pixFindLargestRectangle(pix, polarity, &box, NULL) == 1) {
             boxDestroy(&box);
@@ -1990,7 +2025,7 @@ PIX     *pix;
  *          then found by taking the Max.
  * </pre>
  */
-l_int32
+l_ok
 pixFindLargestRectangle(PIX         *pixs,
                         l_int32      polarity,
                         BOX        **pbox,
