@@ -94,7 +94,7 @@
  *          this region unchanged.
  * </pre>
  */
-l_int32
+l_ok
 pixSetSelectCmap(PIX     *pixs,
                  BOX     *box,
                  l_int32  sindex,
@@ -215,7 +215,7 @@ PIXCMAP   *cmap;
  *          second because their value exceeds the size of the map.
  * </pre>
  */
-l_int32
+l_ok
 pixColorGrayRegionsCmap(PIX     *pixs,
                         BOXA    *boxa,
                         l_int32  type,
@@ -323,7 +323,7 @@ PIXCMAP   *cmap;
  *          original pixel color.
  * </pre>
  */
-l_int32
+l_ok
 pixColorGrayCmap(PIX     *pixs,
                  BOX     *box,
                  l_int32  type,
@@ -391,7 +391,7 @@ PIXCMAP  *cmap;
  *          for this expansion, it returns 1 (error).
  * </pre>
  */
-l_int32
+l_ok
 pixColorGrayMaskedCmap(PIX     *pixs,
                        PIX     *pixm,
                        l_int32  type,
@@ -488,7 +488,7 @@ PIXCMAP   *cmap;
  *      (5) See pixColorGrayCmap() for usage.
  * </pre>
  */
-l_int32
+l_ok
 addColorizedGrayToCmap(PIXCMAP  *cmap,
                        l_int32   type,
                        l_int32   rval,
@@ -579,7 +579,7 @@ NUMA    *na;
  *          is full, an error is returned.
  * </pre>
  */
-l_int32
+l_ok
 pixSetSelectMaskedCmap(PIX     *pixs,
                        PIX     *pixm,
                        l_int32  x,
@@ -622,8 +622,7 @@ PIXCMAP   *cmap;
 
         /* replace pixel value sindex by index when fg pixel in pixmc
          * overlays it */
-    w = pixGetWidth(pixs);
-    h = pixGetHeight(pixs);
+    pixGetDimensions(pixs, &w, &h, NULL);
     datas = pixGetData(pixs);
     wpls = pixGetWpl(pixs);
     wm = pixGetWidth(pixm);
@@ -638,15 +637,6 @@ PIXCMAP   *cmap;
             if (j + x < 0  || j + x >= w) continue;
             if (GET_DATA_BIT(linem, j)) {
                 switch (d) {
-                case 1:
-                    val = GET_DATA_BIT(lines, x + j);
-                    if (val == sindex) {
-                        if (index == 0)
-                            CLEAR_DATA_BIT(lines, x + j);
-                        else
-                            SET_DATA_BIT(lines, x + j);
-                    }
-                    break;
                 case 2:
                     val = GET_DATA_DIBIT(lines, x + j);
                     if (val == sindex)
@@ -699,7 +689,7 @@ PIXCMAP   *cmap;
  *          colormap is already full.
  * </pre>
  */
-l_int32
+l_ok
 pixSetMaskedCmap(PIX      *pixs,
                  PIX      *pixm,
                  l_int32   x,
@@ -749,8 +739,7 @@ PIXCMAP   *cmap;
         for (j = 0; j < wm; j++) {
             if (j + x < 0  || j + x >= w) continue;
             if (GET_DATA_BIT(linem, j)) {  /* paint color */
-                switch (d)
-                {
+                switch (d) {
                 case 2:
                     SET_DATA_DIBIT(line, j + x, index);
                     break;
