@@ -59,6 +59,7 @@
  *           PTA            *ptaRead()
  *           PTA            *ptaReadStream()
  *           PTA            *ptaReadMem()
+ *           l_int32         ptaWriteDebug()
  *           l_int32         ptaWrite()
  *           l_int32         ptaWriteStream()
  *           l_int32         ptaWriteMem()
@@ -315,7 +316,7 @@ ptaClone(PTA  *pta)
  *      This only resets the Pta::n field, for reuse
  * </pre>
  */
-l_int32
+l_ok
 ptaEmpty(PTA  *pta)
 {
     PROCNAME("ptaEmpty");
@@ -337,7 +338,7 @@ ptaEmpty(PTA  *pta)
  * \param[in]    x, y
  * \return  0 if OK, 1 on error
  */
-l_int32
+l_ok
 ptaAddPt(PTA       *pta,
          l_float32  x,
          l_float32  y)
@@ -399,7 +400,7 @@ ptaExtendArrays(PTA  *pta)
  * \param[in]    x, y point values
  * \return  0 if OK; 1 on error
  */
-l_int32
+l_ok
 ptaInsertPt(PTA     *pta,
             l_int32  index,
             l_int32  x,
@@ -442,7 +443,7 @@ l_int32  i, n;
  *          because the function is O(n).
  * </pre>
  */
-l_int32
+l_ok
 ptaRemovePt(PTA     *pta,
             l_int32  index)
 {
@@ -520,7 +521,7 @@ ptaGetCount(PTA  *pta)
  * \param[out]   py [optional] float y value
  * \return  0 if OK; 1 on error
  */
-l_int32
+l_ok
 ptaGetPt(PTA        *pta,
          l_int32     index,
          l_float32  *px,
@@ -550,7 +551,7 @@ ptaGetPt(PTA        *pta,
  * \param[out]   py [optional] integer y value
  * \return  0 if OK; 1 on error
  */
-l_int32
+l_ok
 ptaGetIPt(PTA      *pta,
           l_int32   index,
           l_int32  *px,
@@ -579,7 +580,7 @@ ptaGetIPt(PTA      *pta,
  * \param[in]    x, y
  * \return  0 if OK; 1 on error
  */
-l_int32
+l_ok
 ptaSetPt(PTA       *pta,
          l_int32    index,
          l_float32  x,
@@ -611,7 +612,7 @@ ptaSetPt(PTA       *pta,
  *      (1) This copies the internal arrays into new Numas.
  * </pre>
  */
-l_int32
+l_ok
 ptaGetArrays(PTA    *pta,
              NUMA  **pnax,
              NUMA  **pnay)
@@ -760,6 +761,39 @@ PTA   *pta;
 }
 
 
+/*!
+ * \brief   ptaWriteDebug()
+ *
+ * \param[in]    filename
+ * \param[in]    pta
+ * \param[in]    type  0 for float values; 1 for integer values
+ * \return  0 if OK, 1 on error
+ *
+ * <pre>
+ * Notes:
+ *      (1) Debug version, intended for use in the library when writing
+ *          to files in a temp directory with names that are compiled in.
+ *          This is used instead of ptaWrite() for all such library calls.
+ *      (2) The global variable LeptDebugOK defaults to 0, and can be set
+ *          or cleared by the function setLeptDebugOK().
+ * </pre>
+ */
+l_ok
+ptaWriteDebug(const char  *filename,
+              PTA         *pta,
+              l_int32      type)
+{
+    PROCNAME("ptaWriteDebug");
+
+    if (LeptDebugOK) {
+        return ptaWrite(filename, pta, type);
+    } else {
+        L_INFO("write to named temp file %s is disabled\n", procName, filename);
+        return 0;
+    }
+}
+
+
 /*!
  * \brief   ptaWrite()
  *
@@ -768,7 +802,7 @@ PTA   *pta;
  * \param[in]    type  0 for float values; 1 for integer values
  * \return  0 if OK, 1 on error
  */
-l_int32
+l_ok
 ptaWrite(const char  *filename,
          PTA         *pta,
          l_int32      type)
@@ -801,7 +835,7 @@ FILE    *fp;
  * \param[in]    type  0 for float values; 1 for integer values
  * \return  0 if OK; 1 on error
  */
-l_int32
+l_ok
 ptaWriteStream(FILE    *fp,
                PTA     *pta,
                l_int32  type)
@@ -850,7 +884,7 @@ l_float32  x, y;
  *      (1) Serializes a pta in memory and puts the result in a buffer.
  * </pre>
  */
-l_int32
+l_ok
 ptaWriteMem(l_uint8  **pdata,
             size_t    *psize,
             PTA       *pta,
@@ -966,7 +1000,7 @@ PTAA    *ptaa;
  * \param[in]    copyflag  L_INSERT, L_COPY, L_CLONE
  * \return  0 if OK, 1 on error
  */
-l_int32
+l_ok
 ptaaAddPta(PTAA    *ptaa,
            PTA     *pta,
            l_int32  copyflag)
@@ -1087,7 +1121,7 @@ ptaaGetPta(PTAA    *ptaa,
  * \param[out]   py [optional] float y value
  * \return  0 if OK; 1 on error
  */
-l_int32
+l_ok
 ptaaGetPt(PTAA       *ptaa,
            l_int32     ipta,
            l_int32     jpt,
@@ -1127,7 +1161,7 @@ PTA  *pta;
  * \param[in]    pta to be replicated into the entire ptr array
  * \return  0 if OK; 1 on error
  */
-l_int32
+l_ok
 ptaaInitFull(PTAA  *ptaa,
              PTA   *pta)
 {
@@ -1166,7 +1200,7 @@ PTA     *ptat;
  *      (2) If the index is invalid, return 1 (error)
  * </pre>
  */
-l_int32
+l_ok
 ptaaReplacePta(PTAA    *ptaa,
                l_int32  index,
                PTA     *pta)
@@ -1197,7 +1231,7 @@ l_int32  n;
  * \param[in]    x,y point coordinates
  * \return  0 if OK; 1 on error
  */
-l_int32
+l_ok
 ptaaAddPt(PTAA      *ptaa,
           l_int32    ipta,
           l_float32  x,
@@ -1232,7 +1266,7 @@ PTA  *pta;
  *          and resets the count.
  * </pre>
  */
-l_int32
+l_ok
 ptaaTruncate(PTAA  *ptaa)
 {
 l_int32  i, n, np;
@@ -1360,6 +1394,39 @@ PTAA  *ptaa;
 }
 
 
+/*!
+ * \brief   ptaaWriteDebug()
+ *
+ * \param[in]    filename
+ * \param[in]    ptaa
+ * \param[in]    type  0 for float values; 1 for integer values
+ * \return  0 if OK, 1 on error
+ *
+ * <pre>
+ * Notes:
+ *      (1) Debug version, intended for use in the library when writing
+ *          to files in a temp directory with names that are compiled in.
+ *          This is used instead of ptaaWrite() for all such library calls.
+ *      (2) The global variable LeptDebugOK defaults to 0, and can be set
+ *          or cleared by the function setLeptDebugOK().
+ * </pre>
+ */
+l_ok
+ptaaWriteDebug(const char  *filename,
+               PTAA        *ptaa,
+               l_int32      type)
+{
+    PROCNAME("ptaaWriteDebug");
+
+    if (LeptDebugOK) {
+        return ptaaWrite(filename, ptaa, type);
+    } else {
+        L_INFO("write to named temp file %s is disabled\n", procName, filename);
+        return 0;
+    }
+}
+
+
 /*!
  * \brief   ptaaWrite()
  *
@@ -1368,7 +1435,7 @@ PTAA  *ptaa;
  * \param[in]    type  0 for float values; 1 for integer values
  * \return  0 if OK, 1 on error
  */
-l_int32
+l_ok
 ptaaWrite(const char  *filename,
           PTAA        *ptaa,
           l_int32      type)
@@ -1401,7 +1468,7 @@ FILE    *fp;
  * \param[in]    type  0 for float values; 1 for integer values
  * \return  0 if OK; 1 on error
  */
-l_int32
+l_ok
 ptaaWriteStream(FILE    *fp,
                 PTAA    *ptaa,
                 l_int32  type)
@@ -1443,7 +1510,7 @@ PTA     *pta;
  *      (1) Serializes a ptaa in memory and puts the result in a buffer.
  * </pre>
  */
-l_int32
+l_ok
 ptaaWriteMem(l_uint8  **pdata,
              size_t    *psize,
              PTAA      *ptaa,
