@@ -178,9 +178,9 @@ char    *envsev;
 /*!
  * \brief   returnErrorInt()
  *
- * \param[in]    msg error message
+ * \param[in]    msg        error message
  * \param[in]    procname
- * \param[in]    ival return val
+ * \param[in]    ival       return error val
  * \return  ival typically 1 for an error return
  */
 l_int32
@@ -196,9 +196,9 @@ returnErrorInt(const char  *msg,
 /*!
  * \brief   returnErrorFloat()
  *
- * \param[in]    msg error message
+ * \param[in]    msg        error message
  * \param[in]    procname
- * \param[in]    fval return val
+ * \param[in]    fval       return error val
  * \return  fval
  */
 l_float32
@@ -214,10 +214,10 @@ returnErrorFloat(const char  *msg,
 /*!
  * \brief   returnErrorPtr()
  *
- * \param[in]    msg error message
+ * \param[in]    msg        error message
  * \param[in]    procname
- * \param[in]    pval  return val
- * \return  pval typically null
+ * \param[in]    pval       return error val
+ * \return  pval  typically null for an error return
  */
 void *
 returnErrorPtr(const char  *msg,
@@ -237,7 +237,7 @@ returnErrorPtr(const char  *msg,
  *
  * \param[in]    fname1
  * \param[in]    fname2
- * \param[out]   psame 1 if identical; 0 if different
+ * \param[out]   psame     1 if identical; 0 if different
  * \return  0 if OK, 1 on error
  */
 l_ok
@@ -368,9 +368,9 @@ convertOnBigEnd32(l_uint32  wordin)
  * \brief   fileCorruptByDeletion()
  *
  * \param[in]    filein
- * \param[in]    loc fractional location of start of deletion
- * \param[in]    size fractional size of deletion
- * \param[in]    fileout corrupted file
+ * \param[in]    loc       fractional location of start of deletion
+ * \param[in]    size      fractional size of deletion
+ * \param[in]    fileout   corrupted file
  * \return  0 if OK, 1 on error
  *
  * <pre>
@@ -432,9 +432,9 @@ l_uint8  *datain, *dataout;
  * \brief   fileCorruptByMutation()
  *
  * \param[in]    filein
- * \param[in]    loc fractional location of start of randomization
- * \param[in]    size fractional size of randomization
- * \param[in]    fileout corrupted file
+ * \param[in]    loc       fractional location of start of randomization
+ * \param[in]    size      fractional size of randomization
+ * \param[in]    fileout   corrupted file
  * \return  0 if OK, 1 on error
  *
  * <pre>
@@ -495,9 +495,9 @@ l_uint8  *data;
 /*!
  * \brief   genRandomIntegerInRange()
  *
- * \param[in]    range size of range; must be >= 2
- * \param[in]    seed use 0 to skip; otherwise call srand
- * \param[out]   pval random integer in range {0 ... range-1}
+ * \param[in]    range     size of range; must be >= 2
+ * \param[in]    seed      use 0 to skip; otherwise call srand
+ * \param[out]   pval      random integer in range {0 ... range-1}
  * \return  0 if OK, 1 on error
  *
  * <pre>
@@ -557,7 +557,7 @@ lept_roundftoi(l_float32  fval)
  * \brief   l_hashStringToUint64()
  *
  * \param[in]    str
- * \param[out]   phash hash vale
+ * \param[out]   phash    hash value
  * \return  0 if OK, 1 on error
  *
  * <pre>
@@ -603,12 +603,12 @@ l_uint64  hash, mulp;
  * \brief   l_hashPtToUint64()
  *
  * \param[in]    x, y
- * \param[out]   phash hash value
+ * \param[out]   phash    hash value
  * \return  0 if OK, 1 on error
  *
  * <pre>
  * Notes:
- *      (1) I found that a simple hash function has no collisions for
+ *      (1) This simple hash function has no collisions for
  *          any of 400 million points with x and y up to 20000.
  *      (2) Previously used a much more complicated and slower function:
  *            mulp = 26544357894361;
@@ -641,7 +641,7 @@ l_hashPtToUint64(l_int32    x,
  *
  * \param[in]    nbuckets
  * \param[in]    val
- * \param[out]   phash hash value
+ * \param[out]   phash      hash value
  * \return  0 if OK, 1 on error
  *
  * <pre>
@@ -682,7 +682,7 @@ l_hashFloat64ToUint64(l_int32    nbuckets,
  * \brief   findNextLargerPrime()
  *
  * \param[in]    start
- * \param[out]   pprime first prime larger than %start
+ * \param[out]   pprime    first prime larger than %start
  * \return  0 if OK, 1 on error
  */
 l_ok
@@ -714,10 +714,10 @@ l_int32  i, is_prime;
 /*!
  * \brief   lept_isPrime()
  *
- * \param[in]    n 64-bit unsigned
- * \param[out]   pis_prime 1 if prime, 0 otherwise
- * \param[out]   pfactor [optional] smallest divisor,
- *                       or 0 on error or if prime
+ * \param[in]    n           64-bit unsigned
+ * \param[out]   pis_prime   1 if prime, 0 otherwise
+ * \param[out]   pfactor     [optional] smallest divisor, or 0 on error
+ *                           or if prime
  * \return  0 if OK, 1 on error
  */
 l_ok
@@ -927,8 +927,8 @@ struct rusage  rusage_stop;
 /*!
  * \brief   l_getCurrentTime()
  *
- * \param[out]   sec [optional] in seconds since birth of Unix
- * \param[out]   usec [optional] in microseconds since birth of Unix
+ * \param[out]   sec     [optional] in seconds since birth of Unix
+ * \param[out]   usec    [optional] in microseconds since birth of Unix
  * \return  void
  */
 void
@@ -1073,7 +1073,7 @@ L_WALLTIMER  *timer;
 /*!
  * \brief   stopWallTimer()
  *
- * \param[in,out]  ptimer walltimer-ptr
+ * \param[in,out]  ptimer     walltimer pointer
  * \return  time wall time elapsed in seconds
  */
 l_float32
@@ -1132,7 +1132,11 @@ struct tm  *tptr = &Tm;
            "gmtime" always sets "tm_isdst" to 0, which would tell
            "mktime" to presume that DST is not in effect. */
 #ifdef _WIN32
+  #ifdef _MSC_VER
     gmtime_s(tptr, &ut);
+  #else  /* mingw */
+    tptr = gmtime(&ut);
+  #endif
 #else
     gmtime_r(&ut, tptr);
 #endif
